"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEmployeeFields = exports.getDivisions = exports.getDepartments = exports.getEmployeeLocations = exports.getEmployeeDocumentCategories = exports.getCompanyFileCategories = exports.getTimeOffTypeID = void 0;
const transport_1 = require("../transport");
async function getTimeOffTypeID() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'meta/time_off/types';
    const response = await transport_1.apiRequest.call(this, requestMethod, endPoint, body);
    const timeOffTypeIds = response.body.timeOffTypes;
    for (const item of timeOffTypeIds) {
        returnData.push({
            name: item.name,
            value: item.id,
        });
    }
    return returnData;
}
exports.getTimeOffTypeID = getTimeOffTypeID;
const sort = (a, b) => {
    if (a.name.toLocaleLowerCase() < b.name.toLocaleLowerCase()) {
        return -1;
    }
    if (a.name.toLocaleLowerCase() > b.name.toLocaleLowerCase()) {
        return 1;
    }
    return 0;
};
async function getCompanyFileCategories() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'files/view/';
    const response = await transport_1.apiRequest.call(this, requestMethod, endPoint, body);
    const categories = response.categories;
    for (const category of categories) {
        returnData.push({
            name: category.name,
            value: category.id,
        });
    }
    returnData.sort(sort);
    return returnData;
}
exports.getCompanyFileCategories = getCompanyFileCategories;
async function getEmployeeDocumentCategories() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const id = this.getCurrentNodeParameter('employeeId');
    const endPoint = `employees/${id}/files/view/`;
    const response = await transport_1.apiRequest.call(this, requestMethod, endPoint, body);
    const categories = response.categories;
    for (const category of categories) {
        returnData.push({
            name: category.name,
            value: category.id,
        });
    }
    returnData.sort(sort);
    return returnData;
}
exports.getEmployeeDocumentCategories = getEmployeeDocumentCategories;
async function getEmployeeLocations() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'meta/lists/';
    const fields = (await transport_1.apiRequest.call(this, requestMethod, endPoint, body, {}));
    const options = fields.filter((field) => field.fieldId === 18)[0].options;
    for (const option of options) {
        returnData.push({
            name: option.name,
            value: option.id,
        });
    }
    returnData.sort(sort);
    return returnData;
}
exports.getEmployeeLocations = getEmployeeLocations;
async function getDepartments() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'meta/lists/';
    const fields = (await transport_1.apiRequest.call(this, requestMethod, endPoint, body, {}));
    const options = fields.filter((field) => field.fieldId === 4)[0].options;
    for (const option of options) {
        returnData.push({
            name: option.name,
            value: option.id,
        });
    }
    returnData.sort(sort);
    return returnData;
}
exports.getDepartments = getDepartments;
async function getDivisions() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'meta/lists/';
    const fields = (await transport_1.apiRequest.call(this, requestMethod, endPoint, body, {}));
    const options = fields.filter((field) => field.fieldId === 1355)[0].options;
    for (const option of options) {
        returnData.push({
            name: option.name,
            value: option.id,
        });
    }
    returnData.sort(sort);
    return returnData;
}
exports.getDivisions = getDivisions;
async function getEmployeeFields() {
    const returnData = [];
    const body = {};
    const requestMethod = 'GET';
    const endPoint = 'employees/directory';
    const { fields } = await transport_1.apiRequest.call(this, requestMethod, endPoint, body);
    for (const field of fields) {
        returnData.push({
            name: field.name || field.id,
            value: field.id,
        });
    }
    returnData.sort(sort);
    returnData.unshift({
        name: '[All]',
        value: 'all',
    });
    return returnData;
}
exports.getEmployeeFields = getEmployeeFields;
//# sourceMappingURL=loadOptions.js.map