"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.bubbleApiRequestAllItems = exports.bubbleApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function bubbleApiRequest(method, endpoint, body, qs) {
    const { apiToken, appName, domain, environment, hosting } = (await this.getCredentials('bubbleApi'));
    const rootUrl = hosting === 'bubbleHosted' ? `https://${appName}.bubbleapps.io` : domain;
    const urlSegment = environment === 'development' ? '/version-test/api/1.1' : '/api/1.1';
    const options = {
        headers: {
            'user-agent': 'n8n',
            Authorization: `Bearer ${apiToken}`,
        },
        method,
        uri: `${rootUrl}${urlSegment}${endpoint}`,
        qs,
        body,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.body;
    }
    if (!Object.keys(qs).length) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.bubbleApiRequest = bubbleApiRequest;
async function bubbleApiRequestAllItems(method, endpoint, body, qs) {
    const returnData = [];
    let responseData;
    qs.limit = 100;
    qs.cursor = 0;
    do {
        responseData = await bubbleApiRequest.call(this, method, endpoint, body, qs);
        qs.cursor += qs.limit;
        returnData.push.apply(returnData, responseData.response.results);
    } while (responseData.response.remaining !== 0);
    return returnData;
}
exports.bubbleApiRequestAllItems = bubbleApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map