"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClockifyTrigger = void 0;
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const GenericFunctions_1 = require("./GenericFunctions");
class ClockifyTrigger {
    constructor() {
        this.description = {
            displayName: 'Clockify Trigger',
            icon: 'file:clockify.svg',
            name: 'clockifyTrigger',
            group: ['trigger'],
            version: 1,
            description: 'Listens to Clockify events',
            defaults: {
                name: 'Clockify Trigger',
            },
            inputs: [],
            outputs: ['main'],
            credentials: [
                {
                    name: 'clockifyApi',
                    required: true,
                },
            ],
            polling: true,
            properties: [
                {
                    displayName: 'Workspace Name or ID',
                    name: 'workspaceId',
                    type: 'options',
                    description: 'Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>',
                    typeOptions: {
                        loadOptionsMethod: 'listWorkspaces',
                    },
                    required: true,
                    default: '',
                },
                {
                    displayName: 'Trigger',
                    name: 'watchField',
                    type: 'options',
                    options: [
                        {
                            name: 'New Time Entry',
                            value: 0,
                        },
                    ],
                    required: true,
                    default: 0,
                },
            ],
        };
        this.methods = {
            loadOptions: {
                async listWorkspaces() {
                    const rtv = [];
                    const workspaces = await GenericFunctions_1.clockifyApiRequest.call(this, 'GET', 'workspaces');
                    if (undefined !== workspaces) {
                        workspaces.forEach((value) => {
                            rtv.push({
                                name: value.name,
                                value: value.id,
                            });
                        });
                    }
                    return rtv;
                },
            },
        };
    }
    async poll() {
        const webhookData = this.getWorkflowStaticData('node');
        const triggerField = this.getNodeParameter('watchField');
        const workspaceId = this.getNodeParameter('workspaceId');
        if (!webhookData.userId) {
            const userInfo = await GenericFunctions_1.clockifyApiRequest.call(this, 'GET', 'user');
            webhookData.userId = userInfo.id;
        }
        const qs = {};
        let resource;
        let result = null;
        switch (triggerField) {
            case 0:
            default:
                const workflowTimezone = this.getTimezone();
                resource = `workspaces/${workspaceId}/user/${webhookData.userId}/time-entries`;
                qs.start = webhookData.lastTimeChecked;
                qs.end = (0, moment_timezone_1.default)().tz(workflowTimezone).format('YYYY-MM-DDTHH:mm:ss') + 'Z';
                qs.hydrated = true;
                qs['in-progress'] = false;
                break;
        }
        result = await GenericFunctions_1.clockifyApiRequest.call(this, 'GET', resource, {}, qs);
        webhookData.lastTimeChecked = qs.end;
        if (Array.isArray(result) && result.length !== 0) {
            return [this.helpers.returnJsonArray(result)];
        }
        return null;
    }
}
exports.ClockifyTrigger = ClockifyTrigger;
//# sourceMappingURL=ClockifyTrigger.node.js.map