"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.standardizeOutput = exports.isObject = void 0;
function isObject(maybe) {
    return (typeof maybe === 'object' && maybe !== null && !Array.isArray(maybe) && !(maybe instanceof Date));
}
exports.isObject = isObject;
function isTraversable(maybe) {
    return isObject(maybe) && typeof maybe.toJSON !== 'function' && Object.keys(maybe).length > 0;
}
function standardizeOutput(output) {
    function standardizeOutputRecursive(obj, knownObjects = new WeakSet()) {
        for (const [key, value] of Object.entries(obj)) {
            if (!isTraversable(value))
                continue;
            if (typeof value === 'object' && value !== null) {
                if (knownObjects.has(value)) {
                    continue;
                }
                knownObjects.add(value);
            }
            obj[key] =
                value.constructor.name !== 'Object'
                    ? JSON.stringify(value)
                    : standardizeOutputRecursive(value, knownObjects);
        }
        return obj;
    }
    standardizeOutputRecursive(output);
    return output;
}
exports.standardizeOutput = standardizeOutput;
//# sourceMappingURL=utils.js.map