"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userSearch = exports.categorySearch = exports.textChannelSearch = exports.channelSearch = exports.guildSearch = void 0;
const transport_1 = require("../transport");
const utils_1 = require("../helpers/utils");
async function getGuildId() {
    const guildId = this.getNodeParameter('guildId', undefined, {
        extractValue: true,
    });
    const isOAuth2 = this.getNodeParameter('authentication', '') === 'oAuth2';
    if (isOAuth2) {
        const userGuilds = (await transport_1.discordApiRequest.call(this, 'GET', '/users/@me/guilds'));
        (0, utils_1.checkAccessToGuild)(this.getNode(), guildId, userGuilds);
    }
    return guildId;
}
async function checkBotAccessToGuild(guildId, botId) {
    try {
        const members = await transport_1.discordApiRequest.call(this, 'GET', `/guilds/${guildId}/members`, undefined, { limit: 1000 });
        return members.some((member) => member.user.id === botId);
    }
    catch (error) { }
    return false;
}
async function guildSearch() {
    const response = (await transport_1.discordApiRequest.call(this, 'GET', '/users/@me/guilds'));
    let guilds = [];
    const isOAuth2 = this.getNodeParameter('authentication', 0) === 'oAuth2';
    if (isOAuth2) {
        const botId = (await transport_1.discordApiRequest.call(this, 'GET', '/users/@me')).id;
        for (const guild of response) {
            if (!(await checkBotAccessToGuild.call(this, guild.id, botId)))
                continue;
            guilds.push(guild);
        }
    }
    else {
        guilds = response;
    }
    return {
        results: guilds.map((guild) => ({
            name: guild.name,
            value: guild.id,
            url: `https://discord.com/channels/${guild.id}`,
        })),
    };
}
exports.guildSearch = guildSearch;
async function channelSearch() {
    const guildId = await getGuildId.call(this);
    const response = await transport_1.discordApiRequest.call(this, 'GET', `/guilds/${guildId}/channels`);
    return {
        results: response
            .filter((cannel) => cannel.type !== 4)
            .map((channel) => ({
            name: channel.name,
            value: channel.id,
            url: `https://discord.com/channels/${guildId}/${channel.id}`,
        })),
    };
}
exports.channelSearch = channelSearch;
async function textChannelSearch() {
    const guildId = await getGuildId.call(this);
    const response = await transport_1.discordApiRequest.call(this, 'GET', `/guilds/${guildId}/channels`);
    return {
        results: response
            .filter((cannel) => ![2, 4].includes(cannel.type))
            .map((channel) => ({
            name: channel.name,
            value: channel.id,
            url: `https://discord.com/channels/${guildId}/${channel.id}`,
        })),
    };
}
exports.textChannelSearch = textChannelSearch;
async function categorySearch() {
    const guildId = await getGuildId.call(this);
    const response = await transport_1.discordApiRequest.call(this, 'GET', `/guilds/${guildId}/channels`);
    return {
        results: response
            .filter((cannel) => cannel.type === 4)
            .map((channel) => ({
            name: channel.name,
            value: channel.id,
            url: `https://discord.com/channels/${guildId}/${channel.id}`,
        })),
    };
}
exports.categorySearch = categorySearch;
async function userSearch(filter, paginationToken) {
    const guildId = await getGuildId.call(this);
    const limit = 100;
    const qs = { limit, after: paginationToken };
    const response = await transport_1.discordApiRequest.call(this, 'GET', `/guilds/${guildId}/members`, undefined, qs);
    if (response.length === 0) {
        return {
            results: [],
            paginationToken: undefined,
        };
    }
    let lastUserId;
    if (!(response.length < limit)) {
        lastUserId = response[response.length - 1].user.id;
    }
    return {
        results: response.map(({ user }) => ({
            name: user.username,
            value: user.id,
        })),
        paginationToken: lastUserId,
    };
}
exports.userSearch = userSearch;
//# sourceMappingURL=listSearch.js.map