"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.disqusApiRequestAllItems = exports.disqusApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function disqusApiRequest(method, qs = {}, uri, body = {}, option = {}) {
    const credentials = (await this.getCredentials('disqusApi'));
    qs.api_key = credentials.accessToken;
    const queryStringElements = [];
    for (const key of Object.keys(qs)) {
        if (Array.isArray(qs[key])) {
            qs[key].forEach((value) => {
                queryStringElements.push(`${key}=${value}`);
            });
        }
        else {
            queryStringElements.push(`${key}=${qs[key]}`);
        }
    }
    let options = {
        method,
        body,
        uri: `https://disqus.com/api/3.0/${uri}?${queryStringElements.join('&')}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.disqusApiRequest = disqusApiRequest;
async function disqusApiRequestAllItems(method, qs = {}, uri, body = {}, option = {}) {
    const returnData = [];
    let responseData;
    try {
        do {
            responseData = await disqusApiRequest.call(this, method, qs, uri, body, option);
            qs.cursor = responseData.cursor.id;
            returnData.push.apply(returnData, responseData.response);
        } while (responseData.cursor.more === true && responseData.cursor.hasNext === true);
        return returnData;
    }
    catch (error) {
        throw error;
    }
}
exports.disqusApiRequestAllItems = disqusApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map