"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KoBoToolbox = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const FormDescription_1 = require("./FormDescription");
const SubmissionDescription_1 = require("./SubmissionDescription");
const HookDescription_1 = require("./HookDescription");
const FileDescription_1 = require("./FileDescription");
class KoBoToolbox {
    constructor() {
        this.description = {
            displayName: 'KoBoToolbox',
            name: 'koBoToolbox',
            icon: 'file:koBoToolbox.svg',
            group: ['transform'],
            version: 1,
            description: 'Work with KoBoToolbox forms and submissions',
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            defaults: {
                name: 'KoBoToolbox',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'koBoToolboxApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'File',
                            value: 'file',
                        },
                        {
                            name: 'Form',
                            value: 'form',
                        },
                        {
                            name: 'Hook',
                            value: 'hook',
                        },
                        {
                            name: 'Submission',
                            value: 'submission',
                        },
                    ],
                    default: 'submission',
                    required: true,
                },
                ...FormDescription_1.formOperations,
                ...FormDescription_1.formFields,
                ...HookDescription_1.hookOperations,
                ...HookDescription_1.hookFields,
                ...SubmissionDescription_1.submissionOperations,
                ...SubmissionDescription_1.submissionFields,
                ...FileDescription_1.fileOperations,
                ...FileDescription_1.fileFields,
            ],
        };
        this.methods = {
            loadOptions: {
                loadForms: GenericFunctions_1.loadForms,
            },
        };
    }
    async execute() {
        var _a, _b, _c, _d, _e, _f;
        let responseData;
        let returnData = [];
        const binaryItems = [];
        const items = this.getInputData();
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        for (let i = 0; i < items.length; i++) {
            if (resource === 'form') {
                if (operation === 'get') {
                    const formId = this.getNodeParameter('formId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}`,
                        }),
                    ];
                }
                if (operation === 'getAll') {
                    const formQueryOptions = this.getNodeParameter('options', i);
                    const formFilterOptions = this.getNodeParameter('filters', i);
                    responseData = await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                        url: '/api/v2/assets/',
                        qs: {
                            limit: this.getNodeParameter('limit', i, 1000),
                            ...(formFilterOptions.filter && { q: formFilterOptions.filter }),
                            ...(((_b = (_a = formQueryOptions === null || formQueryOptions === void 0 ? void 0 : formQueryOptions.sort) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.ordering) && {
                                ordering: (((_d = (_c = formQueryOptions === null || formQueryOptions === void 0 ? void 0 : formQueryOptions.sort) === null || _c === void 0 ? void 0 : _c.value) === null || _d === void 0 ? void 0 : _d.descending) ? '-' : '') +
                                    ((_f = (_e = formQueryOptions === null || formQueryOptions === void 0 ? void 0 : formQueryOptions.sort) === null || _e === void 0 ? void 0 : _e.value) === null || _f === void 0 ? void 0 : _f.ordering),
                            }),
                        },
                        scroll: this.getNodeParameter('returnAll', i),
                    });
                }
                if (operation === 'redeploy') {
                    const formId = this.getNodeParameter('formId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'PATCH',
                            url: `/api/v2/assets/${formId}/deployment/`,
                        }),
                    ];
                }
            }
            if (resource === 'submission') {
                const formId = this.getNodeParameter('formId', i);
                if (operation === 'getAll') {
                    const submissionQueryOptions = this.getNodeParameter('options', i);
                    const filterJson = this.getNodeParameter('filterJson', i, null);
                    responseData = await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                        url: `/api/v2/assets/${formId}/data/`,
                        qs: {
                            limit: this.getNodeParameter('limit', i, 1000),
                            ...(filterJson && { query: filterJson }),
                            ...(submissionQueryOptions.sort && { sort: submissionQueryOptions.sort }),
                            ...(submissionQueryOptions.fields && {
                                fields: JSON.stringify((0, GenericFunctions_1.parseStringList)(submissionQueryOptions.fields)),
                            }),
                        },
                        scroll: this.getNodeParameter('returnAll', i),
                    });
                    if (submissionQueryOptions.reformat) {
                        responseData = responseData.map((submission) => {
                            return (0, GenericFunctions_1.formatSubmission)(submission, (0, GenericFunctions_1.parseStringList)(submissionQueryOptions.selectMask), (0, GenericFunctions_1.parseStringList)(submissionQueryOptions.numberMask));
                        });
                    }
                    if (submissionQueryOptions.download) {
                        for (const submission of responseData) {
                            binaryItems.push(await GenericFunctions_1.downloadAttachments.call(this, submission, submissionQueryOptions));
                        }
                    }
                }
                if (operation === 'get') {
                    const submissionId = this.getNodeParameter('submissionId', i);
                    const options = this.getNodeParameter('options', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}/data/${submissionId}`,
                            qs: {
                                ...(options.fields && {
                                    fields: JSON.stringify((0, GenericFunctions_1.parseStringList)(options.fields)),
                                }),
                            },
                        }),
                    ];
                    if (options.reformat) {
                        responseData = responseData.map((submission) => {
                            return (0, GenericFunctions_1.formatSubmission)(submission, (0, GenericFunctions_1.parseStringList)(options.selectMask), (0, GenericFunctions_1.parseStringList)(options.numberMask));
                        });
                    }
                    if (options.download) {
                        for (const submission of responseData) {
                            binaryItems.push(await GenericFunctions_1.downloadAttachments.call(this, submission, options));
                        }
                    }
                }
                if (operation === 'delete') {
                    const id = this.getNodeParameter('submissionId', i);
                    await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                        method: 'DELETE',
                        url: `/api/v2/assets/${formId}/data/${id}`,
                    });
                    responseData = [
                        {
                            success: true,
                        },
                    ];
                }
                if (operation === 'getValidation') {
                    const submissionId = this.getNodeParameter('submissionId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}/data/${submissionId}/validation_status/`,
                        }),
                    ];
                }
                if (operation === 'setValidation') {
                    const submissionId = this.getNodeParameter('submissionId', i);
                    const status = this.getNodeParameter('validationStatus', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'PATCH',
                            url: `/api/v2/assets/${formId}/data/${submissionId}/validation_status/`,
                            body: {
                                'validation_status.uid': status,
                            },
                        }),
                    ];
                }
            }
            if (resource === 'hook') {
                const formId = this.getNodeParameter('formId', i);
                if (operation === 'getAll') {
                    responseData = await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                        url: `/api/v2/assets/${formId}/hooks/`,
                        qs: {
                            limit: this.getNodeParameter('limit', i, 1000),
                        },
                        scroll: this.getNodeParameter('returnAll', i),
                    });
                }
                if (operation === 'get') {
                    const hookId = this.getNodeParameter('hookId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}/hooks/${hookId}`,
                        }),
                    ];
                }
                if (operation === 'retryAll') {
                    const hookId = this.getNodeParameter('hookId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'PATCH',
                            url: `/api/v2/assets/${formId}/hooks/${hookId}/retry/`,
                        }),
                    ];
                }
                if (operation === 'getLogs') {
                    const hookId = this.getNodeParameter('hookId', i);
                    const startDate = this.getNodeParameter('startDate', i, null);
                    const endDate = this.getNodeParameter('endDate', i, null);
                    const status = this.getNodeParameter('status', i, null);
                    responseData = await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                        url: `/api/v2/assets/${formId}/hooks/${hookId}/logs/`,
                        qs: {
                            ...(startDate && { start: startDate }),
                            ...(endDate && { end: endDate }),
                            ...(status && { status }),
                        },
                    });
                }
                if (operation === 'retryOne') {
                    const hookId = this.getNodeParameter('hookId', i);
                    const logId = this.getNodeParameter('logId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'PATCH',
                            url: `/api/v2/assets/${formId}/hooks/${hookId}/logs/${logId}/retry/`,
                        }),
                    ];
                }
            }
            if (resource === 'file') {
                const formId = this.getNodeParameter('formId', i);
                if (operation === 'getAll') {
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}/files`,
                            qs: {
                                file_type: 'form_media',
                            },
                            scroll: true,
                        }),
                    ];
                }
                if (operation === 'get') {
                    const fileId = this.getNodeParameter('fileId', i);
                    const download = this.getNodeParameter('download', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            url: `/api/v2/assets/${formId}/files/${fileId}`,
                        }),
                    ];
                    if ((responseData === null || responseData === void 0 ? void 0 : responseData[0]) && download) {
                        const binaryPropertyName = this.getNodeParameter('binaryPropertyName', i);
                        const binaryItem = {
                            json: responseData[0],
                            binary: {},
                        };
                        const response = await GenericFunctions_1.koBoToolboxRawRequest.call(this, {
                            url: `/api/v2/assets/${formId}/files/${fileId}/content`,
                            encoding: 'arraybuffer',
                        });
                        console.dir(response);
                        binaryItem.binary[binaryPropertyName] = await this.helpers.prepareBinaryData(response, responseData[0].metadata.filename);
                        binaryItems.push(binaryItem);
                    }
                }
                if (operation === 'delete') {
                    const fileId = this.getNodeParameter('fileId', i);
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'DELETE',
                            url: `/api/v2/assets/${formId}/files/${fileId}`,
                        }),
                    ];
                }
                if (operation === 'create') {
                    const fileMode = this.getNodeParameter('fileMode', i);
                    const body = {
                        description: 'Uploaded file',
                        file_type: 'form_media',
                    };
                    if ('binary' === fileMode) {
                        const binaryPropertyName = this.getNodeParameter('binaryPropertyName', i);
                        const item = items[i].binary;
                        const binaryData = item[binaryPropertyName];
                        body.base64Encoded = 'data:' + binaryData.mimeType + ';base64,' + binaryData.data;
                        body.metadata = {
                            filename: binaryData.fileName,
                        };
                    }
                    else {
                        const fileUrl = this.getNodeParameter('fileUrl', i);
                        body.metadata = {
                            redirect_url: fileUrl,
                        };
                    }
                    responseData = [
                        await GenericFunctions_1.koBoToolboxApiRequest.call(this, {
                            method: 'POST',
                            url: `/api/v2/assets/${formId}/files/`,
                            body,
                        }),
                    ];
                }
            }
            returnData = returnData.concat(responseData);
        }
        return binaryItems.length > 0 ? [binaryItems] : [this.helpers.returnJsonArray(returnData)];
    }
}
exports.KoBoToolbox = KoBoToolbox;
//# sourceMappingURL=KoBoToolbox.node.js.map