"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPath = exports.microsoftApiRequestAllItemsDelta = exports.microsoftApiRequestAllItemsSkip = exports.microsoftApiRequestAllItems = exports.microsoftApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const luxon_1 = require("luxon");
async function microsoftApiRequest(method, resource, body = {}, qs = {}, uri, headers = {}, option = { json: true }) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://graph.microsoft.com/v1.0/me${resource}`,
    };
    try {
        Object.assign(options, option);
        if (Object.keys(headers).length !== 0) {
            options.headers = Object.assign({}, options.headers, headers);
        }
        if (Object.keys(qs).length === 0) {
            delete options.qs;
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'microsoftOneDriveOAuth2Api', options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.microsoftApiRequest = microsoftApiRequest;
async function microsoftApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.$top = 100;
    do {
        responseData = await microsoftApiRequest.call(this, method, endpoint, body, query, uri);
        uri = responseData['@odata.nextLink'];
        if (uri === null || uri === void 0 ? void 0 : uri.includes('$top')) {
            delete query.$top;
        }
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData['@odata.nextLink'] !== undefined);
    return returnData;
}
exports.microsoftApiRequestAllItems = microsoftApiRequestAllItems;
async function microsoftApiRequestAllItemsSkip(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.$top = 100;
    query.$skip = 0;
    do {
        responseData = await microsoftApiRequest.call(this, method, endpoint, body, query);
        query.$skip += query.$top;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.value.length !== 0);
    return returnData;
}
exports.microsoftApiRequestAllItemsSkip = microsoftApiRequestAllItemsSkip;
async function microsoftApiRequestAllItemsDelta(link, lastDate, eventType) {
    var _a, _b;
    const returnData = [];
    let responseData;
    let deltaLink = '';
    let uri = link;
    do {
        responseData = (await microsoftApiRequest.call(this, 'GET', '', {}, {}, uri));
        uri = responseData['@odata.nextLink'];
        for (const value of responseData.value) {
            if (value.fileSystemInfo) {
                const updatedTimeStamp = (_a = value.fileSystemInfo) === null || _a === void 0 ? void 0 : _a.lastModifiedDateTime;
                const createdTimeStamp = (_b = value.fileSystemInfo) === null || _b === void 0 ? void 0 : _b.createdDateTime;
                if (eventType === 'created') {
                    if (luxon_1.DateTime.fromISO(createdTimeStamp) >= lastDate) {
                        returnData.push(value);
                    }
                }
                if (eventType === 'updated') {
                    if (luxon_1.DateTime.fromISO(updatedTimeStamp) >= lastDate &&
                        luxon_1.DateTime.fromISO(createdTimeStamp) < lastDate) {
                        returnData.push(value);
                    }
                }
            }
        }
        deltaLink = responseData['@odata.deltaLink'] || '';
    } while (responseData['@odata.nextLink'] !== undefined);
    return { deltaLink, returnData };
}
exports.microsoftApiRequestAllItemsDelta = microsoftApiRequestAllItemsDelta;
async function getPath(itemId) {
    var _a;
    const responseData = (await microsoftApiRequest.call(this, 'GET', '', {}, {}, `https://graph.microsoft.com/v1.0/me/drive/items/${itemId}`));
    if (responseData.folder) {
        return ((_a = responseData === null || responseData === void 0 ? void 0 : responseData.parentReference) === null || _a === void 0 ? void 0 : _a.path) + `/${responseData === null || responseData === void 0 ? void 0 : responseData.name}`;
    }
    else {
        const workflow = this.getWorkflow();
        const node = this.getNode();
        this.logger.error(`There was a problem in '${node.name}' node in workflow '${workflow.id}': 'Item to watch is not a folder'`, {
            node: node.name,
            workflowId: workflow.id,
            error: 'Item to watch is not a folder',
        });
        throw new n8n_workflow_1.NodeApiError(this.getNode(), {
            error: 'Item to watch is not a folder',
        });
    }
}
exports.getPath = getPath;
//# sourceMappingURL=GenericFunctions.js.map