"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = exports.description = void 0;
const transport_1 = require("../../transport");
const descriptions_1 = require("../../descriptions");
const utilities_1 = require("../../../../../../utils/utilities");
const properties = [
    descriptions_1.teamRLC,
    descriptions_1.channelRLC,
    {
        displayName: 'Name',
        name: 'name',
        type: 'string',
        default: '',
        placeholder: 'e.g. My New Channel name',
        description: 'The name of the channel',
    },
    {
        displayName: 'Options',
        name: 'options',
        type: 'collection',
        default: {},
        placeholder: 'Add Option',
        options: [
            {
                displayName: 'Description',
                name: 'description',
                type: 'string',
                default: '',
                description: 'The description of the channel',
                typeOptions: {
                    rows: 2,
                },
            },
        ],
    },
];
const displayOptions = {
    show: {
        resource: ['channel'],
        operation: ['update'],
    },
};
exports.description = (0, utilities_1.updateDisplayOptions)(displayOptions, properties);
async function execute(i) {
    const teamId = this.getNodeParameter('teamId', i, '', { extractValue: true });
    const channelId = this.getNodeParameter('channelId', i, '', { extractValue: true });
    const newName = this.getNodeParameter('name', i);
    const newDescription = this.getNodeParameter('options.description', i, '');
    const body = {};
    if (newName) {
        body.displayName = newName;
    }
    if (newDescription) {
        body.description = newDescription;
    }
    await transport_1.microsoftApiRequest.call(this, 'PATCH', `/v1.0/teams/${teamId}/channels/${channelId}`, body);
    return { success: true };
}
exports.execute = execute;
//# sourceMappingURL=update.operation.js.map