"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = exports.description = void 0;
const descriptions_1 = require("../../descriptions");
const transport_1 = require("../../transport");
const utilities_1 = require("../../../../../../utils/utilities");
const descriptions_2 = require("../../../../../../utils/descriptions");
const properties = [
    {
        displayName: 'Tasks For',
        name: 'tasksFor',
        default: 'member',
        required: true,
        type: 'options',
        description: 'Whether to retrieve the tasks for a user or for a plan',
        options: [
            {
                name: 'Group Member',
                value: 'member',
                description: 'Tasks assigned to group member',
            },
            {
                name: 'Plan',
                value: 'plan',
                description: 'Tasks in group plan',
            },
        ],
    },
    descriptions_1.groupRLC,
    {
        ...descriptions_1.planRLC,
        displayOptions: {
            show: {
                tasksFor: ['plan'],
            },
        },
    },
    ...descriptions_2.returnAllOrLimit,
];
const displayOptions = {
    show: {
        resource: ['task'],
        operation: ['getAll'],
    },
};
exports.description = (0, utilities_1.updateDisplayOptions)(displayOptions, properties);
async function execute(i) {
    const tasksFor = this.getNodeParameter('tasksFor', i);
    const returnAll = this.getNodeParameter('returnAll', i);
    if (tasksFor === 'member') {
        const memberId = (await transport_1.microsoftApiRequest.call(this, 'GET', '/v1.0/me'))
            .id;
        if (returnAll) {
            return await transport_1.microsoftApiRequestAllItems.call(this, 'value', 'GET', `/v1.0/users/${memberId}/planner/tasks`);
        }
        else {
            const limit = this.getNodeParameter('limit', i);
            const responseData = await transport_1.microsoftApiRequestAllItems.call(this, 'value', 'GET', `/v1.0/users/${memberId}/planner/tasks`, {});
            return responseData.splice(0, limit);
        }
    }
    else {
        const planId = this.getNodeParameter('planId', i, '', { extractValue: true });
        if (returnAll) {
            return await transport_1.microsoftApiRequestAllItems.call(this, 'value', 'GET', `/v1.0/planner/plans/${planId}/tasks`);
        }
        else {
            const limit = this.getNodeParameter('limit', i);
            const responseData = await transport_1.microsoftApiRequestAllItems.call(this, 'value', 'GET', `/v1.0/planner/plans/${planId}/tasks`, {});
            return responseData.splice(0, limit);
        }
    }
}
exports.execute = execute;
//# sourceMappingURL=getAll.operation.js.map