"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanData = exports.cleanDataPreviousApiVersions = exports.mindeeApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function mindeeApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const resource = this.getNodeParameter('resource', 0);
    let service;
    if (resource === 'receipt') {
        service = 'mindeeReceiptApi';
    }
    else {
        service = 'mindeeInvoiceApi';
    }
    const version = this.getNodeParameter('apiVersion', 0);
    const url = version === 1
        ? `https://api.mindee.net/products${path}`
        : `https://api.mindee.net/v1/products/mindee${path}`;
    const options = {
        headers: {},
        method,
        body,
        qs,
        uri: url,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (Object.keys(qs).length === 0) {
            delete options.qs;
        }
        if (Object.keys(option).length !== 0) {
            Object.assign(options, option);
        }
        return await this.helpers.requestWithAuthentication.call(this, service, options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.mindeeApiRequest = mindeeApiRequest;
function cleanDataPreviousApiVersions(predictions) {
    const newData = {};
    for (const key of Object.keys(predictions[0])) {
        const data = predictions[0][key];
        if (key === 'taxes' && data.length) {
            newData[key] = {
                amount: data[0].amount,
                rate: data[0].rate,
            };
        }
        else if (key === 'locale') {
            newData.currency = data.currency;
            newData.locale = data.value;
        }
        else {
            newData[key] =
                data.value || data.name || data.raw || data.degrees || data.amount || data.iban;
        }
    }
    return newData;
}
exports.cleanDataPreviousApiVersions = cleanDataPreviousApiVersions;
function cleanData(document) {
    const prediction = document.inference.prediction;
    const newData = {};
    newData.id = document.id;
    newData.name = document.name;
    newData.number_of_pages = document.n_pages;
    for (const key of Object.keys(prediction)) {
        const data = prediction[key];
        if (key === 'taxes' && data.length) {
            newData[key] = {
                amount: data[0].amount,
                rate: data[0].rate,
            };
        }
        else if (key === 'locale') {
            newData.currency = data.currency;
            newData.locale = data.value;
        }
        else if (key === 'line_items') {
            const lineItems = [];
            for (const lineItem of data) {
                lineItems.push({
                    description: lineItem.description,
                    product_code: lineItem.product_code,
                    quantity: lineItem.quantity,
                    tax_amount: lineItem.tax_amount,
                    tax_rate: lineItem.tax_rate,
                    total_amount: lineItem.total_amount,
                    unit_price: lineItem.unit_price,
                });
            }
            newData[key] = lineItems;
        }
        else {
            newData[key] =
                data.value || data.name || data.raw || data.degrees || data.amount || data.iban;
        }
    }
    return newData;
}
exports.cleanData = cleanData;
//# sourceMappingURL=GenericFunctions.js.map