"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.searchTables = void 0;
const ssh2_1 = require("ssh2");
const transport_1 = require("../transport");
async function searchTables() {
    const credentials = await this.getCredentials('mySql');
    const nodeOptions = this.getNodeParameter('options', 0);
    let sshClient = undefined;
    if (credentials.sshTunnel) {
        sshClient = new ssh2_1.Client();
    }
    const pool = await (0, transport_1.createPool)(credentials, nodeOptions, sshClient);
    try {
        const connection = await pool.getConnection();
        const query = 'SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE table_schema = ?';
        const values = [credentials.database];
        const formatedQuery = connection.format(query, values);
        const response = (await connection.query(formatedQuery))[0];
        connection.release();
        const results = response.map((table) => ({
            name: table.table_name || table.TABLE_NAME,
            value: table.table_name || table.TABLE_NAME,
        }));
        return { results };
    }
    catch (error) {
        throw error;
    }
    finally {
        if (sshClient) {
            sshClient.end();
        }
        await pool.end();
    }
}
exports.searchTables = searchTables;
//# sourceMappingURL=listSearch.js.map