"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenAi = void 0;
const descriptions_1 = require("../../utils/descriptions");
const ImageDescription_1 = require("./ImageDescription");
const TextDescription_1 = require("./TextDescription");
const ChatDescription_1 = require("./ChatDescription");
class OpenAi {
    constructor() {
        this.description = {
            displayName: 'OpenAI',
            name: 'openAi',
            hidden: true,
            icon: 'file:openAi.svg',
            group: ['transform'],
            version: [1, 1.1],
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Consume Open AI',
            defaults: {
                name: 'OpenAI',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'openAiApi',
                    required: true,
                },
            ],
            requestDefaults: {
                ignoreHttpStatusErrors: true,
                baseURL: 'https://api.openai.com',
            },
            properties: [
                descriptions_1.oldVersionNotice,
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Chat',
                            value: 'chat',
                        },
                        {
                            name: 'Image',
                            value: 'image',
                        },
                        {
                            name: 'Text',
                            value: 'text',
                        },
                    ],
                    default: 'text',
                },
                ...ChatDescription_1.chatOperations,
                ...ChatDescription_1.chatFields,
                ...ImageDescription_1.imageOperations,
                ...ImageDescription_1.imageFields,
                ...TextDescription_1.textOperations,
                ...TextDescription_1.textFields,
            ],
        };
    }
}
exports.OpenAi = OpenAi;
//# sourceMappingURL=OpenAi.node.js.map