"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getColumnsWithoutColumnToMatchOn = exports.getColumnsMultiOptions = exports.getColumns = void 0;
const utils_1 = require("../helpers/utils");
const transport_1 = require("../transport");
async function getColumns() {
    const credentials = (await this.getCredentials('postgres'));
    const options = { nodeVersion: this.getNode().typeVersion };
    const { db, sshClient } = await (0, transport_1.configurePostgres)(credentials, options);
    const schema = this.getNodeParameter('schema', 0, {
        extractValue: true,
    });
    const table = this.getNodeParameter('table', 0, {
        extractValue: true,
    });
    try {
        const columns = await (0, utils_1.getTableSchema)(db, schema, table);
        return columns.map((column) => ({
            name: column.column_name,
            value: column.column_name,
            description: `Type: ${column.data_type.toUpperCase()}, Nullable: ${column.is_nullable}`,
        }));
    }
    catch (error) {
        throw error;
    }
    finally {
        if (sshClient) {
            sshClient.end();
        }
        if (!db.$pool.ending)
            await db.$pool.end();
    }
}
exports.getColumns = getColumns;
async function getColumnsMultiOptions() {
    const returnData = await getColumns.call(this);
    const returnAll = { name: '*', value: '*', description: 'All columns' };
    return [returnAll, ...returnData];
}
exports.getColumnsMultiOptions = getColumnsMultiOptions;
async function getColumnsWithoutColumnToMatchOn() {
    const columnToMatchOn = this.getNodeParameter('columnToMatchOn');
    const returnData = await getColumns.call(this);
    return returnData.filter((column) => column.value !== columnToMatchOn);
}
exports.getColumnsWithoutColumnToMatchOn = getColumnsWithoutColumnToMatchOn;
//# sourceMappingURL=loadOptions.js.map