"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = exports.description = void 0;
const transport_1 = require("../../transport");
const descriptions_1 = require("../../descriptions");
const utilities_1 = require("../../../../utils/utilities");
const properties = [
    descriptions_1.caseRLC,
    {
        displayName: 'Attachment Name or ID',
        name: 'attachmentId',
        type: 'options',
        default: '',
        required: true,
        description: 'ID of the attachment. Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>.',
        typeOptions: {
            loadOptionsMethod: 'loadCaseAttachments',
            loadOptionsDependsOn: ['caseId.value'],
        },
    },
    {
        displayName: 'Options',
        name: 'options',
        type: 'collection',
        placeholder: 'Add Option',
        default: {},
        options: [
            {
                displayName: 'File Name',
                name: 'fileName',
                type: 'string',
                default: '',
                description: 'Rename the file when downloading',
            },
            {
                displayName: 'Data Property Name',
                name: 'dataPropertyName',
                type: 'string',
                default: 'data',
                description: 'Name of the binary property to which write the data of the attachment',
            },
        ],
    },
];
const displayOptions = {
    show: {
        resource: ['case'],
        operation: ['getAttachment'],
    },
};
exports.description = (0, utilities_1.updateDisplayOptions)(displayOptions, properties);
async function execute(i) {
    var _a, _b;
    const caseId = this.getNodeParameter('caseId', i, '', { extractValue: true });
    const options = this.getNodeParameter('options', i);
    const attachmentId = this.getNodeParameter('attachmentId', i);
    const requestOptions = {
        useStream: true,
        resolveWithFullResponse: true,
        encoding: null,
        json: false,
    };
    const response = await transport_1.theHiveApiRequest.call(this, 'GET', `/v1/case/${caseId}/attachment/${attachmentId}/download`, undefined, undefined, undefined, requestOptions);
    const mimeType = (_b = (_a = response.headers) === null || _a === void 0 ? void 0 : _a['content-type']) !== null && _b !== void 0 ? _b : undefined;
    let fileName = options.fileName || 'attachment';
    if (!options.fileName && response.headers['content-disposition'] !== undefined) {
        const contentDisposition = response.headers['content-disposition'];
        const fileNameMatch = contentDisposition.match(/filename="(.+)"/);
        if (fileNameMatch !== null) {
            fileName = fileNameMatch[1];
        }
    }
    const newItem = {
        json: {
            _id: attachmentId,
            caseId,
            fileName,
            mimeType,
        },
        binary: {},
    };
    newItem.binary[options.dataPropertyName || 'data'] =
        await this.helpers.prepareBinaryData(response.body, fileName, mimeType);
    const executionData = this.helpers.constructExecutionMetaData([newItem], {
        itemData: { item: i },
    });
    return executionData;
}
exports.execute = execute;
//# sourceMappingURL=getAttachment.operation.js.map