"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.todoistSyncRequest = exports.todoistApiRequest = exports.FormatDueDatetime = void 0;
const n8n_workflow_1 = require("n8n-workflow");
function FormatDueDatetime(isoString) {
    return isoString.replace(new RegExp('.000Z$'), 'Z');
}
exports.FormatDueDatetime = FormatDueDatetime;
async function todoistApiRequest(method, resource, body = {}, qs = {}) {
    const authentication = this.getNodeParameter('authentication', 0);
    const endpoint = 'api.todoist.com/rest/v2';
    const options = {
        method,
        qs,
        uri: `https://${endpoint}${resource}`,
        json: true,
    };
    if (Object.keys(body).length !== 0) {
        options.body = body;
    }
    try {
        const credentialType = authentication === 'apiKey' ? 'todoistApi' : 'todoistOAuth2Api';
        return await this.helpers.requestWithAuthentication.call(this, credentialType, options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.todoistApiRequest = todoistApiRequest;
async function todoistSyncRequest(body = {}, qs = {}) {
    const authentication = this.getNodeParameter('authentication', 0, 'oAuth2');
    const options = {
        headers: {},
        method: 'POST',
        qs,
        uri: 'https://api.todoist.com/sync/v9/sync',
        json: true,
    };
    if (Object.keys(body).length !== 0) {
        options.body = body;
    }
    try {
        const credentialType = authentication === 'oAuth2' ? 'todoistOAuth2Api' : 'todoistApi';
        return await this.helpers.requestWithAuthentication.call(this, credentialType, options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.todoistSyncRequest = todoistSyncRequest;
//# sourceMappingURL=GenericFunctions.js.map