"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.zendeskApiRequestAllItems = exports.zendeskApiRequest = void 0;
function getUri(resource, subdomain) {
    if (resource.includes('webhooks')) {
        return `https://${subdomain}.zendesk.com/api/v2${resource}`;
    }
    else {
        return `https://${subdomain}.zendesk.com/api/v2${resource}.json`;
    }
}
async function zendeskApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    let credentials;
    if (authenticationMethod === 'apiToken') {
        credentials = (await this.getCredentials('zendeskApi'));
    }
    else {
        credentials = (await this.getCredentials('zendeskOAuth2Api'));
    }
    let options = {
        method,
        qs,
        body,
        uri: uri || getUri(resource, credentials.subdomain),
        json: true,
        qsStringifyOptions: {
            arrayFormat: 'brackets',
        },
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    const credentialType = authenticationMethod === 'apiToken' ? 'zendeskApi' : 'zendeskOAuth2Api';
    return await this.helpers.requestWithAuthentication.call(this, credentialType, options);
}
exports.zendeskApiRequest = zendeskApiRequest;
async function zendeskApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    do {
        responseData = await zendeskApiRequest.call(this, method, resource, body, query, uri);
        uri = responseData.next_page;
        returnData.push.apply(returnData, responseData[propertyName]);
        const limit = query.limit;
        if (limit && limit <= returnData.length) {
            return returnData;
        }
    } while (responseData.next_page !== undefined && responseData.next_page !== null);
    return returnData;
}
exports.zendeskApiRequestAllItems = zendeskApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map